## Faktoren eignen sich, um Daten zu kategorisieren.
# Die Elemente der Eingabe werden effizient intern auf Integer abgebildet.
# Der Faktor erkennt so gleichartige Elemente und fasst diese als eine Kategorie, ein "level" zusammen.
# Beispiel:
> fac = factor(c("blue","green","yellow","green","blue"))
> fac
[1] blue   green  yellow green  blue  
Levels: blue green yellow
# Hier wurden nun die Levels nicht extra spezifiert, weshalb der Faktor für alle verschiedenen Elemente ein level erzeugt hat.

# Es gibt aber auch die Möglichkeit, die levels explizit anzugeben:
> fac = factor(c("blue","green","yellow","green","blue"), levels = c("green"))
> fac
[1] <NA>  green <NA>  green <NA> 
Levels: green
# In diesem Beispiel wurde nur "green" als Kategorie angegeben. Alle Elemente, die der Faktor nun nicht zuordnen kann,
# markiert er mit <NA> (not available)

# Mit Faktoren lassen sich nun nützliche Dinge anstellen.
# Frage: Wie sieht die Verteilung aus, wenn man 1000-mal eine Zahl von 1 bis 10 zufällig wählt?
> fac = factor(sample(1:10, 1000, replace = TRUE), levels = c(1:10))
> table(fac)
fac
  1   2   3   4   5   6   7   8   9  10 
104 119 110 104 103  79  82 101  98 100 

# Auch eine wichtige Eigenschaft: Faktoren lassen sich nach ihren Levels ordnen.
# Macht man keine Angabe, wird automatisch unordered gewaehlt.
# Wichtige Info: Die Reihenfolge der Levels, sollte man welche festlegen, wird so übernommen! Beispiel:
> fac = factor(sample(1:10, 10, replace = TRUE), levels = c(5,2,7))
> fac
 [1] 5    <NA> <NA> 7    5    <NA> <NA> <NA> <NA> <NA>
Levels: 5 2 7

# Mit einem weiteren Faktor-Parameter lässt sich nun eine Ordnung erzwingen. Diese ist nun fest definiert durch den Anwender:
> fac = factor(sample(1:10, 10, replace = TRUE), levels = c(5,2,7), ordered = TRUE)
> fac
 [1] 2    <NA> <NA> <NA> 7    <NA> <NA> <NA> <NA> <NA>
Levels: 5 < 2 < 7